var prefs = (function (adw1, gtk4) {
    'use strict';

    const ExtensionUtils = imports.misc.extensionUtils;
    const SettingsPath = "org.gnome.shell.extensions.do-not-disturb-while-screen-sharing-or-recording";
    const DoNotDisturbOnScreenSharingSetting = "dnd-on-screen-sharing";
    const DoNotDisturbOnScreenRecordingSetting = "dnd-on-screen-recording";
    const IsWaylandSetting = "is-wayland";
    class SettingsManager {
        constructor() {
            this.settings = null;
        }
        getSettings() {
            if (!this.settings) {
                this.settings = ExtensionUtils.getSettings(SettingsPath);
            }
            return this.settings;
        }
        getShouldDndOnScreenSharing() {
            return this.getSettings().get_boolean(DoNotDisturbOnScreenSharingSetting);
        }
        setShouldDndOnScreenSharing(value) {
            this.getSettings().set_boolean(DoNotDisturbOnScreenSharingSetting, value);
        }
        getShouldDndOnScreenRecording() {
            return this.getSettings().get_boolean(DoNotDisturbOnScreenRecordingSetting);
        }
        setShouldDndOnScreenRecording(value) {
            this.getSettings().set_boolean(DoNotDisturbOnScreenRecordingSetting, value);
        }
        getIsWayland() {
            return this.getSettings().get_boolean(IsWaylandSetting);
        }
        setIsWayland(value) {
            this.getSettings().set_boolean(IsWaylandSetting, value);
        }
        connectToChanges(settingName, func) {
            return this.getSettings().connect(`changed::${settingName}`, func);
        }
        disconnect(subscriptionId) {
            this.getSettings().disconnect(subscriptionId);
        }
        dispose() {
            this.settings = null;
        }
    }

    function init() { }
    function fillPreferencesWindow(window) {
        const page = new adw1.PreferencesPage();
        const settings = new SettingsManager();
        const group = new adw1.PreferencesGroup({
            title: "Automatic Do Not Disturb Mode",
            description: "Select what events should cause Do Not Disturb mode to be switched on automatically",
        });
        setupScreenRecording(settings, group);
        setupScreenSharing(settings, group);
        page.add(group);
        window.add(page);
    }
    function setupScreenRecording(settings, group) {
        const row = new adw1.ActionRow({
            title: "Screen Recording"
        });
        const toggle = new gtk4.Switch({
            active: settings.getShouldDndOnScreenRecording(),
            valign: gtk4.Align.CENTER,
        });
        toggle.connect("state-set", (_, state) => {
            settings.setShouldDndOnScreenRecording(state);
            return false;
        });
        row.add_suffix(toggle);
        row.activatable_widget = toggle;
        group.add(row);
    }
    function setupScreenSharing(settings, group) {
        const isWayland = settings.getIsWayland();
        const row = new adw1.ActionRow({
            title: "Screen Sharing",
            subtitle: !isWayland ?
                "Disabled, since it works only on Wayland sessions, and you are running X11" :
                "",
            sensitive: isWayland
        });
        const toggle = new gtk4.Switch({
            active: isWayland ? settings.getShouldDndOnScreenSharing() : false,
            valign: gtk4.Align.CENTER,
            sensitive: isWayland
        });
        toggle.connect("state-set", (_, state) => {
            settings.setShouldDndOnScreenSharing(state);
            return false;
        });
        row.add_suffix(toggle);
        row.activatable_widget = toggle;
        group.add(row);
    }
    var prefs = { init, fillPreferencesWindow };

    return prefs;

})(imports.gi.Adw, imports.gi.Gtk);
var init = prefs.init;
var fillPreferencesWindow = prefs.fillPreferencesWindow;
